use crate::prelude::*;

#[derive(Deserialize, Debug)]
pub struct Params {
    file_id: Uuid,
}

pub async fn delete(
    Query(params): Query<Params>,
    State(state): State<AppState>,
    claims: Claims,
) -> GeneralResult<StatusCode> {
    db::file::get_permissions(params.file_id, claims.user_id, &state.pool)
        .await
        .can_write_guard()?;

    let deleted = db::file::delete(params.file_id, &state.pool)
        .await
        .handle_internal("Error deleting the file")?;
    if !deleted {
        return Err(GeneralError::message(
            StatusCode::NOT_FOUND,
            "Item not found",
        )); // Will not happen most of the time due to can write guard
    }

    state
        .storage
        .delete(params.file_id)
        .await
        .handle_internal("Error deleting the file")?;

    Ok(StatusCode::NO_CONTENT)
}
