use validator::Validate;

use crate::prelude::*;

#[derive(Deserialize, Debug, Validate)]
pub struct Params {
    #[validate(email)]
    username: String,
    #[validate(email)]
    email: String,
}

pub async fn put(
    State(pool): State<Pool>,
    claims: Claims,
    Json(params): Json<Params>,
) -> GeneralResult<Json<db::users::UserInfo>> {
    params.validate().handle_validation()?;
    db::users::update(claims.user_id, &params.username, &params.email, &pool)
        .await
        .handle_internal("Error updating the user")
        .map(Json)
}
